<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-images?lang_cible=fr_fem
// ** ne pas modifier le fichier **

return [

	// I
	'images_description' => 'Filtres de transformation d’images et de couleurs',
	'images_slogan' => 'Filtres de transformation d’images et de couleurs',
];
